@@ -344,7 +344,7 @@ syriac_engine_fc_class_init (PangoEngineShapeClass *class)
 }
 
 PANGO_ENGINE_SHAPE_DEFINE_TYPE (SyriacEngineFc, syriac_engine_fc,
-				syriac_engine_fc_class_init, NULL);
+				syriac_engine_fc_class_init, NULL)
 
 void 
 PANGO_MODULE_ENTRY(init) (GTypeModule *module)
